@@ -1,33 +1,45 @@
 /*
- * Copyright (C) 2005 - 2008  Zarafa B.V.
- *
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
  * as published by the Free Software Foundation with the following additional 
  * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
  * 
- * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of the Program
- * under the AGPL does not imply a trademark license. Therefore any rights,
- * title and interest in our trademarks remain entirely with us.
- * However, if you propagate an unmodified version of the Program you are 
- * required to use the term "Zarafa" to indicate that you distribute the 
- * Program. Furthermore you may use our trademarks where it is necessary to 
- * indicate the intended purpose of a product or service provided you use it in 
- * accordance with honest practices in industrial or commercial matters.
- * If you want to propagate modified versions of the Program under the name
- * "Zarafa" or "Zarafa Server", you may only do so if you have a written
- * permission by Zarafa B.V. (to acquire a permission please contact Zarafa at
- * trademark@zarafa.com).
- * The user interface of the software displays a attribution notice containing
- * the term "Zarafa" and/or the Logo of Zarafa. You have to preserve these
- * attribution notices when you propagate unmodified or modified versions of
- * the Program.
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Affero General Public License for more details.
- * 
+ *  
  * You should have received a copy of the GNU Affero General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  * 
@@ -37,6 +49,7 @@
 #define ECCONFIG_H
 
 #include <map>
+#include <set>
 #include <list>
 #include <string>
 #include <string.h>
@@ -67,7 +80,14 @@ struct settingcompare
 
 #define MAXLINELEN 4096
 
+class ECConfig;
+
 typedef map<settingkey_t, char *, settingcompare> settingmap_t;
+typedef bool (ECConfig::*directive_func_t)(const char *, unsigned int);
+typedef struct {
+	const char			*lpszDirective;
+	directive_func_t	fExecute;
+} directive_t;
 
 /*
  * Flags for the InitDefaults & InitConfigFile functions
@@ -97,6 +117,9 @@ public:
 private:
 	bool	InitDefaults(unsigned int ulFlags);
 	bool	InitConfigFile(unsigned int ulFlags);
+	bool	ReadConfigFile(const char *szFilename, unsigned int ulFlags);
+
+	bool	HandleInclude(const char *lpszArgs, unsigned int ulFlags);
 
 	char*	GetMapEntry(settingmap_t *lpMap, const char *szName);
 	char*	GetAlias(const char *szAlias);
@@ -107,6 +130,9 @@ private:
 	void	CleanupMap(settingmap_t *lpMap);
 	bool	CopyConfigSetting(const configsetting_t *lpsSetting, settingkey_t *lpsKey);
 
+	void	SetPathTo(const char *lpszDir);
+	void	RestorePath();
+
 private:
 	const configsetting_t *m_lpDefaults;
 	const char* m_szConfigFile;
@@ -117,7 +143,11 @@ private:
 	settingmap_t		m_mapSettings;
 	settingmap_t		m_mapAliases;
 	list<string>	warnings;
-	list<string>	errors;
+	list<string>		errors;
+	set<string>			m_readFiles;
+	list<string>		m_pathStack;
+
+	static const directive_t	s_sDirectives[];
 };
 
 #endif // ECCONFIG_H
