@@ -1,33 +1,45 @@
 /*
- * Copyright (C) 2005 - 2008  Zarafa B.V.
- *
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
  * as published by the Free Software Foundation with the following additional 
  * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
  * 
- * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of the Program
- * under the AGPL does not imply a trademark license. Therefore any rights,
- * title and interest in our trademarks remain entirely with us.
- * However, if you propagate an unmodified version of the Program you are 
- * required to use the term "Zarafa" to indicate that you distribute the 
- * Program. Furthermore you may use our trademarks where it is necessary to 
- * indicate the intended purpose of a product or service provided you use it in 
- * accordance with honest practices in industrial or commercial matters.
- * If you want to propagate modified versions of the Program under the name
- * "Zarafa" or "Zarafa Server", you may only do so if you have a written
- * permission by Zarafa B.V. (to acquire a permission please contact Zarafa at
- * trademark@zarafa.com).
- * The user interface of the software displays a attribution notice containing
- * the term "Zarafa" and/or the Logo of Zarafa. You have to preserve these
- * attribution notices when you propagate unmodified or modified versions of
- * the Program.
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Affero General Public License for more details.
- * 
+ *  
  * You should have received a copy of the GNU Affero General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  * 
@@ -55,10 +67,17 @@ DEFINE_GUID(ZARAFA_STORE_DELEGATE_GUID,
 // same as MUIDECSAB
 #define MUIDECSAB_SERVER "\xAC\x21\xA9\x50\x40\xD3\xEE\x48\xB3\x19\xFB\xA7\x53\x30\x44\x25"
 
+// {0x7976ED54D0D211DD9705BE5055D89593}
+#define MUIDECSI_SERVER "\x79\x76\xED\x54\xD0\xD2\x11\xDD\x97\x05\xBE\x50\x55\xD8\x95\x93"
+
 // {5ABAE40E-1DF7-4f3d-964D-658A79924E9D}
 DEFINE_GUID(ZARAFA_SAB_GUID, 
 0x5abae40e, 0x1df7, 0x4f3d, 0x96, 0x4d, 0x65, 0x8a, 0x79, 0x92, 0x4e, 0x9d);
 
+// {A7D80ED6-D027-11DD-B0B6-645055D89593}
+DEFINE_GUID(IID_IECSingleInstance,
+0xa7d80ed6, 0xd027, 0x11dd, 0xb0, 0xb6, 0x64, 0x50, 0x55, 0xd8, 0x95, 0x93);
+
 // {20C5963F-0E0B-4d7f-B75D-8ACD88727119}
 DEFINE_GUID(IID_IECSpooler, 
 0x20c5963f, 0xe0b, 0x4d7f, 0xb7, 0x5d, 0x8a, 0xcd, 0x88, 0x72, 0x71, 0x19);
@@ -140,6 +159,17 @@ DEFINE_GUID(IID_ECMsgStoreOnline,
 DEFINE_GUID(IID_IECExportAddressbookChanges,
 0x09f33e65, 0x6886, 0x4bf2, 0xa2, 0x6f, 0xfa, 0x0e, 0xc4, 0xe9, 0x42, 0x16);
 
+// {1843c89e-2411-11de-be6e-7c3256d89593}
+DEFINE_GUID(IID_IECImportAddressbookChanges,
+0x1843c89e, 0x2411, 0x11de, 0xbe, 0x6e, 0x7c, 0x32, 0x56, 0xd8, 0x95, 0x93);
+
+// {1c2d9897-f459-4a55-9d11-cd9e7c7551ee}
+DEFINE_GUID(IID_IECServerBehavior,
+0x1c2d9897, 0xf459, 0x4a55, 0x9d, 0x11, 0xcd, 0x9e, 0x7c, 0x75, 0x51, 0xee);
+
+// {7175DE83-33A2-4d69-8D9A-17726EB2FCDD}
+DEFINE_GUID(IID_IECServerMimic, 
+0x7175de83, 0x33a2, 0x4d69, 0x8d, 0x9a, 0x17, 0x72, 0x6e, 0xb2, 0xfc, 0xdd);
 
 //FIXME: Move those guids non zarafa guids, only linux?
 
@@ -157,3 +187,4 @@ DEFINE_GUID(IID_ISensNetwork,
 #define STATIC_GUID_FAVSUBTREE "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01"
 
 #endif
+
