@@ -1,33 +1,45 @@
 /*
- * Copyright (C) 2005 - 2008  Zarafa B.V.
- *
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
  * as published by the Free Software Foundation with the following additional 
  * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
  * 
- * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of the Program
- * under the AGPL does not imply a trademark license. Therefore any rights,
- * title and interest in our trademarks remain entirely with us.
- * However, if you propagate an unmodified version of the Program you are 
- * required to use the term "Zarafa" to indicate that you distribute the 
- * Program. Furthermore you may use our trademarks where it is necessary to 
- * indicate the intended purpose of a product or service provided you use it in 
- * accordance with honest practices in industrial or commercial matters.
- * If you want to propagate modified versions of the Program under the name
- * "Zarafa" or "Zarafa Server", you may only do so if you have a written
- * permission by Zarafa B.V. (to acquire a permission please contact Zarafa at
- * trademark@zarafa.com).
- * The user interface of the software displays a attribution notice containing
- * the term "Zarafa" and/or the Logo of Zarafa. You have to preserve these
- * attribution notices when you propagate unmodified or modified versions of
- * the Program.
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Affero General Public License for more details.
- * 
+ *  
  * You should have received a copy of the GNU Affero General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  * 
@@ -54,6 +66,7 @@
 //#define PR_EC_PROFILE_USER			PROP_TAG(PT_BINARY,		PR_EC_BASE+0x08)
 #define PR_EC_LAST_CONNECTIONTYPE		PROP_TAG(PT_LONG,		PR_EC_BASE+0x09)
 #define PR_EC_CONNECTION_TIMEOUT		PROP_TAG(PT_LONG,		PR_EC_BASE+0x0A)
+#define PR_EC_OFFLINE_PATH				PROP_TAG(PT_STRING8,	PR_EC_BASE+0x10) /* same as PR_EC_CONTACT_ENTRYID, but on different objects! */
 
 // Used for proxy settings
 #define PR_EC_PROXY_HOST				PROP_TAG(PT_STRING8,	PR_EC_BASE+0x0B)
@@ -62,12 +75,15 @@
 #define PR_EC_PROXY_PASSWORD			PROP_TAG(PT_STRING8,	PR_EC_BASE+0x0E)
 #define PR_EC_PROXY_FLAGS				PROP_TAG(PT_LONG,		PR_EC_BASE+0x0F)
 
+
 ////////////////////////////////////////////////////////////////////////////////
 
 // The property under which we actually save the PR_ENTRYID in recipient tables
 #define PR_EC_CONTACT_ENTRYID			PROP_TAG(PT_BINARY,		PR_EC_BASE+0x10)
 #define PR_EC_HIERARCHYID				PROP_TAG(PT_LONG,		PR_EC_BASE+0x11)
+#define PR_EC_STOREGUID					PROP_TAG(PT_BINARY,		PR_EC_BASE+0x12)
 /* 0x6712 == PR_RANK (edkmdb.h) */
+#define PR_EC_COMPANYID					PROP_TAG(PT_LONG,		PR_EC_BASE+0x13)
 
 #define PR_EC_QUOTA_MAIL_TIME			PROP_TAG(PT_SYSTIME,	PR_EC_BASE+0x20)
 //NOTE:	The properties PR_QUOTA_WARNING_THRESHOLD, PR_QUOTA_SEND_THRESHOLD, PR_QUOTA_RECEIVE_THRESHOLD
@@ -97,6 +113,11 @@
 #define PR_EC_STATS_SESSION_CPU_SYSTEM	PROP_TAG(PT_DOUBLE,		PR_EC_BASE+0x4b)
 #define PR_EC_STATS_SESSION_CPU_REAL	PROP_TAG(PT_DOUBLE,		PR_EC_BASE+0x4c)
 
+#define PR_EC_STATS_SESSION_GROUP_ID	PROP_TAG(PT_LONGLONG,	PR_EC_BASE+0x4d)
+#define PR_EC_STATS_SESSION_PEER_PID	PROP_TAG(PT_LONG,		PR_EC_BASE+0x4e)
+#define PR_EC_STATS_SESSION_CLIENT_VERSION	PROP_TAG(PT_STRING8,	PR_EC_BASE+0x4f)
+#define PR_EC_STATS_SESSION_CLIENT_APPLICATION PROP_TAG(PT_STRING8, PR_EC_BASE+0x50)
+
 #define PR_EC_OUTOFOFFICE				PROP_TAG(PT_BOOLEAN,	PR_EC_BASE+0x60)
 #define PR_EC_OUTOFOFFICE_MSG			PROP_TAG(PT_STRING8,	PR_EC_BASE+0x61)
 #define PR_EC_OUTOFOFFICE_SUBJECT		PROP_TAG(PT_STRING8, 	PR_EC_BASE+0x62)
@@ -126,8 +147,6 @@
 #define PR_EC_CLIENT_SUBMIT_DATE		PROP_TAG(PT_SYSTIME, PR_EC_BASE+0x86)
 // Stores the DATE part of an e-mail, disregarding timezone
 #define PR_EC_MESSAGE_DELIVERY_DATE		PROP_TAG(PT_SYSTIME, PR_EC_BASE+0x87)
-// License flags (on IMsgStore)
-#define PR_EC_LICENSE_FLAGS				PROP_TAG(PT_I8,		PR_EC_BASE+0x88)
 
 // addressbook entryids of users which are allowed to send as
 #define PR_EC_SENDAS_USER_ENTRYIDS		PROP_TAG(PT_MV_BINARY,	PR_EC_BASE+0x83)
@@ -135,6 +154,10 @@
 // addressbook ADS legacyExchange DN
 #define PR_EC_EXCHANGE_DN			PROP_TAG(PT_STRING8,	PR_EC_BASE+0x88)
 
+// server path to home server of a user
+#define PR_EC_SERVERPATH				PROP_TAG(PT_STRING8,	PR_EC_BASE+0xC0)
+#define PR_EC_HOMESERVER_NAME			PROP_TAG(PT_STRING8,	PR_EC_BASE+0xC1)
+
 #define PR_EC_SEARCHFOLDER_STATUS		PROP_TAG(PT_LONG,	PR_EC_BASE+0x90)
 
 #define PR_EC_OFFLINE_SYNC_STATUS		PROP_TAG(PT_BINARY,	PR_EC_BASE+0xA0)
@@ -146,7 +169,7 @@
 
 // Properties for IMailUsers
 #define PR_EC_NONACTIVE					PROP_TAG(PT_BOOLEAN,	PR_EC_BASE+0xB0) // Maps to 'ulIsNonAcive' in ECUser
-#define PR_EC_ADMINISTRATOR				PROP_TAG(PT_BOOLEAN,	PR_EC_BASE+0xB1) // Maps to 'ulIsAdmin' in ECUser
+#define PR_EC_ADMINISTRATOR				PROP_TAG(PT_LONG,		PR_EC_BASE+0xB1) // Maps to 'ulIsAdmin' in ECUser
 
 
 // Flags for PR_EC_FLAGS
