@@ -1,33 +1,45 @@
 /*
- * Copyright (C) 2005 - 2008  Zarafa B.V.
- *
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
  * as published by the Free Software Foundation with the following additional 
  * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
  * 
- * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of the Program
- * under the AGPL does not imply a trademark license. Therefore any rights,
- * title and interest in our trademarks remain entirely with us.
- * However, if you propagate an unmodified version of the Program you are 
- * required to use the term "Zarafa" to indicate that you distribute the 
- * Program. Furthermore you may use our trademarks where it is necessary to 
- * indicate the intended purpose of a product or service provided you use it in 
- * accordance with honest practices in industrial or commercial matters.
- * If you want to propagate modified versions of the Program under the name
- * "Zarafa" or "Zarafa Server", you may only do so if you have a written
- * permission by Zarafa B.V. (to acquire a permission please contact Zarafa at
- * trademark@zarafa.com).
- * The user interface of the software displays a attribution notice containing
- * the term "Zarafa" and/or the Logo of Zarafa. You have to preserve these
- * attribution notices when you propagate unmodified or modified versions of
- * the Program.
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Affero General Public License for more details.
- * 
+ *  
  * You should have received a copy of the GNU Affero General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  * 
@@ -39,6 +51,8 @@
 #include "edkmdb.h"
 #include <string>
 
+#include "ECDefs.h"
+
 class Util {
 public:
 	static std::string GetServerNameFromPath(const char *szPath);
@@ -59,8 +73,9 @@ public:
 	static HRESULT	HrCopyActions(ACTIONS *lpDest, ACTIONS *lpSrc, void *lpBase);
 	static HRESULT	HrCopyAction(ACTION *lpDest, ACTION *lpSrc, void *lpBase);
 	static HRESULT	HrCopySRowSet(LPSRowSet lpDest, LPSRowSet lpSrc, void *lpBase);
-	static HRESULT	HrCopySRow(LPSRow lpDest, LPSRow lpSrc);
+	static HRESULT	HrCopySRow(LPSRow lpDest, LPSRow lpSrc, void *lpBase);
 
+	static HRESULT	HrCopyBinary(ULONG ulSize, LPBYTE lpSrc, ULONG *lpulDestSize, LPBYTE *lppDest);
 	static HRESULT	HrCopyEntryId(ULONG ulSize, LPENTRYID lpSrc, ULONG *lpulDestSize, LPENTRYID* lppDest);
 
 	static HRESULT	CompareProp(LPSPropValue lpProp1, LPSPropValue lpProp2, int* lpCompareResult);
@@ -71,6 +86,7 @@ public:
 	static LONG		HrFindPropInArray(LPSPropTagArray lpPropTags, ULONG ulPropTag);
 
 	static char CharFromHtmlEntity(const std::string &strEntity);
+	static bool validateHtmlEntity(const std::string &strEntity);
 	static std::string HtmlEntityFromChar(unsigned char c);
 
 	static HRESULT	HrTextToHtml(IStream *text, IStream *html);
@@ -87,11 +103,40 @@ public:
 	static std::string bin2hex(ULONG inLength, LPBYTE input);
 	static HRESULT bin2hex(ULONG inLength, LPBYTE input, char **output, void *parent = NULL);
 	static HRESULT hex2bin(char *input, size_t len, ULONG *outLength, LPBYTE *output, void *parent = NULL);
-	static HRESULT hex2bin(std::string input, std::string *output);
+	static HRESULT hex2bin(const std::string &input, std::string *output);
 
+	static HRESULT FileLFtoCRLF(FILE *fin, FILE** fout);
 	static void BufferLFtoCRLF(size_t size, const char *input, char *output, size_t *outsize);
 
-	static bool	StrCaseCompare(std::string& strInput, std::string strFind, size_t pos = 0); 
+	static bool StrCaseCompare(const std::string &strInput, const char *lpFind, size_t pos = 0);
+
+	static HRESULT HrMapFileToString(FILE *f, std::string *lpstrBuffer, int *lpSize = NULL);
+	static HRESULT HrMapFileToBuffer(FILE *f, char **lppBuffer, int *lpSize, bool *lpImmap);
+	static void HrUnmapFileBuffer(char *lpBuffer, int ulSize, bool bImmap);
+
+	/* DoCopyTo/DoCopyProps functions & their helpers */
+	static HRESULT FindInterface(LPCIID lpIID, ULONG ulIIDs, LPCIID lpIIDs);
+	static HRESULT CopyStream(LPSTREAM lpSrc, LPSTREAM lpDest);
+	static HRESULT CopyRecipients(LPMESSAGE lpSrc, LPMESSAGE lpDest);
+	static HRESULT CopyAttachmentInstance(LPATTACH lpSrcAttach, LPATTACH lpDestAttach);
+	static HRESULT CopyAttachmentProps(LPATTACH lpSrcAttach, LPATTACH lpDestAttach, LPSPropTagArray lpExcludeProps = NULL);
+	static HRESULT CopyAttachments(LPMESSAGE lpSrc, LPMESSAGE lpDest);
+	static HRESULT CopyHierarchy(LPMAPIFOLDER lpSrc, LPMAPIFOLDER lpDest, ULONG ulFlags, ULONG ulUIParam, LPMAPIPROGRESS lpProgress);
+	static HRESULT CopyContents(ULONG ulWhat, LPMAPIFOLDER lpSrc, LPMAPIFOLDER lpDest, ULONG ulFlags, ULONG ulUIParam, LPMAPIPROGRESS lpProgress);
+	static HRESULT TryOpenProperty(ULONG ulPropType, ULONG ulSrcPropTag, LPMAPIPROP lpPropSrc, ULONG ulDestPropTag, LPMAPIPROP lpPropDest,
+								   LPSTREAM *lppSrcStream, LPSTREAM *lppDestStream);
+	static HRESULT AddProblemToArray(LPSPropProblem lpProblem, LPSPropProblemArray *lppProblems);
+
+	static HRESULT DoCopyTo(LPCIID lpSrcInterface, LPVOID lpSrcObj, ULONG ciidExclude, LPCIID rgiidExclude,
+							LPSPropTagArray lpExcludeProps, ULONG ulUIParam, LPMAPIPROGRESS lpProgress, LPCIID lpDestInterface,
+							LPVOID lpDestObj, ULONG ulFlags, LPSPropProblemArray * lppProblems);
+	static HRESULT DoCopyProps(LPCIID lpSrcInterface, LPVOID lpSrcObj, LPSPropTagArray lpIncludeProps, ULONG ulUIParam,
+							   LPMAPIPROGRESS lpProgress, LPCIID lpDestInterface, LPVOID lpDestObj, ULONG ulFlags,
+							   LPSPropProblemArray * lppProblems);
+
+	static HRESULT HrGetQuotaStatus(IMsgStore *lpMsgStore, LPECQUOTA lpsQuota, LPECQUOTASTATUS *lppsQuotaStatus);
+
+	static HRESULT HrDeleteResidualProps(LPMESSAGE lpDestMsg, LPMESSAGE lpSourceMsg, LPSPropTagArray lpsValidProps);
 
 private:
 	static unsigned char x2b(char c);	// hex2bin helper
