@@ -1,33 +1,45 @@
 /*
- * Copyright (C) 2005 - 2008  Zarafa B.V.
- *
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
  * as published by the Free Software Foundation with the following additional 
  * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
  * 
- * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of the Program
- * under the AGPL does not imply a trademark license. Therefore any rights,
- * title and interest in our trademarks remain entirely with us.
- * However, if you propagate an unmodified version of the Program you are 
- * required to use the term "Zarafa" to indicate that you distribute the 
- * Program. Furthermore you may use our trademarks where it is necessary to 
- * indicate the intended purpose of a product or service provided you use it in 
- * accordance with honest practices in industrial or commercial matters.
- * If you want to propagate modified versions of the Program under the name
- * "Zarafa" or "Zarafa Server", you may only do so if you have a written
- * permission by Zarafa B.V. (to acquire a permission please contact Zarafa at
- * trademark@zarafa.com).
- * The user interface of the software displays a attribution notice containing
- * the term "Zarafa" and/or the Logo of Zarafa. You have to preserve these
- * attribution notices when you propagate unmodified or modified versions of
- * the Program.
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Affero General Public License for more details.
- * 
+ *  
  * You should have received a copy of the GNU Affero General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  * 
@@ -110,7 +122,10 @@
 
 // In PSETID_Appointment
 #define dispidSendAsICAL					0x8200	//PT_BOOLEAN
+#define dispidAppointmentSequenceNumber		0x8201	//PT_LONG
+#define dispidApptSeqTime					0x8202	//PT_SYSTIME
 #define dispidBusyStatus					0x8205	//PT_LONG
+#define dispidApptAuxFlags					0x8207	//PT_LONG
 #define dispidLocation						0x8208	//PT_STRING8
 #define dispidApptStartWhole				0x820D	//PT_SYSTIME
 #define dispidApptEndWhole					0x820E	//PT_SYSTIME
@@ -121,14 +136,15 @@
 #define dispidMeetingStatus					0x8217	//PT_LONG
 #define dispidResponseStatus				0x8218	//PT_LONG
 #define dispidRecurring						0x8223	//PT_BOOLEAN
+#define dispidIntendedBusyStatus			0x8224	//PT_LONG
 #define dispidRecurringBase					0x8228	//PT_SYSTIME
 #define dispidRequestSent					0x8229	//PT_BOOLEAN
 #define dispidRecurrenceType				0x8231	//PT_LONG
 #define dispidRecurrencePattern				0x8232	//PT_STRING8
 #define dispidTimeZoneData					0x8233	//PT_BINARY - official name dispidTimeZoneStruct
 #define dispidTimeZone						0x8234	//PT_STRING8
-#define dispidRecurrenceStart				0x8235	//PT_SYSTIME
-#define dispidRecurrenceEnd					0x8236	//PT_SYSTIME
+#define dispidClipStart						0x8235	//PT_SYSTIME
+#define dispidClipEnd						0x8236	//PT_SYSTIME
 #define dispidAllAttendeesString			0x8238	//PT_STRING8
 #define dispidToAttendeesString				0x823B	//PT_STRING8
 #define dispidCCAttendeesString				0x823C	//PT_STRING8
@@ -136,12 +152,14 @@
 #define dispidNetMeetingServer				0x8242	//PT_STRING8
 #define dispidNetMeetingOrganizerAlias		0x8243	//PT_STRING8
 #define dispidNetMeetingAutoStart			0x8244	//PT_BOOLEAN
+#define dispidAutoStartWhen					0x8245	//PT_LONG
 #define dispidConferenceServerAllowExternal 0x8246	//PT_BOOLEAN
 #define dispidNetMeetingDocPathName			0x8247	//PT_STRING8
 #define dispidNetShowURL					0x8248	//PT_STRING8
 #define dispidConferenceServerPassword		0x8249	//PT_STRING8
 // A counter proposal is when the recipient of the request has proposed a new time for the meeting
 #define dispidApptCounterProposal			0x8257	//PT_BOOLEAN
+#define dispidApptReplyTime					0x8220	//PT_SYSTIME
 
 // New in OLK 2007
 #define dispidApptTZDefStartDisplay			0x825E
@@ -151,8 +169,22 @@
 // In PSETID_Meeting
 #define dispidMeetingLocation				0x0002	//PT_STRING8
 #define dispidGlobalObjectID				0x0003	//PT_BINARY
+#define dispidIsRecurring					0x0005	//PT_BOOLEAN
 #define dispidMeetingRecurrenceId			0x0023	//PT_BINARY
 #define dispidMeetingMessageClass			0x0024	//PT_STRING8
+#define dispidAttendeeCriticalChange		0x1
+#define dispidOwnerCriticalChange			0x1a
+
+//Timestamp used as ID by Caldav
+#define dispidApptTsRef						0x0025	//PT_STRING8
+//FolderID used by Caldav
+#define dispidFldID							0x0026	//PT_STRING8
+
+//In PSETID_Zarafa_CalDav
+#define dispidMozLastAck					0x0001	//PT_SYSTIME	X-MOZ-LAST-ACK 
+#define dispidMozGen						0x0002	//PT_LONG		X-MOZ-GENERATION
+#define dispidMozSnoozeSuffixTime			0x0003	//PT_SYSTIME	X-MOZ-SNOOZE-TIME suffix 
+#define dispidMozSendInvite					0x0004	//PT_BOOLEAN	X-MOZ-SEND-INVITATIONS
 
 // In PSETID_Common
 #define dispidReminderMinutesBeforeStart	0x8501	//PT_LONG
@@ -161,9 +193,10 @@
 #define dispidPrivate						0x8506	//PT_BOOLEAN
 #define dispidNoAging						0x850E	//PT_BOOLEAN
 #define dispidFormStorage					0x850F
+#define dispidSideEffect					0x8510	//PT_LONG
 #define dispidRemoteStatus					0x8511
 #define dispidPageDirStream					0x8513
-#define dispidSmartNoAttach					0x8514
+#define dispidSmartNoAttach					0x8514	//PT_BOOLEAN
 #define dispidCommonStart					0x8516	//PT_SYSTIME
 #define dispidCommonEnd						0x8517	//PT_SYSTIME
 
