@@ -1,33 +1,45 @@
 /*
- * Copyright (C) 2005 - 2008  Zarafa B.V.
- *
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
  * as published by the Free Software Foundation with the following additional 
  * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
  * 
- * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of the Program
- * under the AGPL does not imply a trademark license. Therefore any rights,
- * title and interest in our trademarks remain entirely with us.
- * However, if you propagate an unmodified version of the Program you are 
- * required to use the term "Zarafa" to indicate that you distribute the 
- * Program. Furthermore you may use our trademarks where it is necessary to 
- * indicate the intended purpose of a product or service provided you use it in 
- * accordance with honest practices in industrial or commercial matters.
- * If you want to propagate modified versions of the Program under the name
- * "Zarafa" or "Zarafa Server", you may only do so if you have a written
- * permission by Zarafa B.V. (to acquire a permission please contact Zarafa at
- * trademark@zarafa.com).
- * The user interface of the software displays a attribution notice containing
- * the term "Zarafa" and/or the Logo of Zarafa. You have to preserve these
- * attribution notices when you propagate unmodified or modified versions of
- * the Program.
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Affero General Public License for more details.
- * 
+ *  
  * You should have received a copy of the GNU Affero General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  * 
@@ -68,6 +80,14 @@ void	RTimeToFileTime(LONG rtime, FILETIME *pft);
 void	FileTimeToRTime(FILETIME *pft, LONG* prtime);
 HRESULT	UnixTimeToRTime(time_t unixtime, LONG *rtime);
 HRESULT	RTimeToUnixTime(LONG rtime, time_t *unixtime);
+time_t SystemTimeToUnixTime(SYSTEMTIME stime);
+SYSTEMTIME UnixTimeToSystemTime(time_t unixtime);
+SYSTEMTIME TMToSystemTime(struct tm t);
+struct tm SystemTimeToTM(SYSTEMTIME stime);
+
+inline double difftimeval(struct timeval *ptstart, struct timeval *ptend) {
+	return 1000000 * (ptend->tv_sec - ptstart->tv_sec) + (ptend->tv_usec - ptstart->tv_usec);
+}
 
 struct tm* gmtime_safe(const time_t* timer, struct tm *result);
 
